Documentation
¶
Index ¶
Constants ¶
const ( // NonceFile is written by cloud-init as the last thing it does. // The file will contain the machine's nonce. The filename is // relative to the Juju data-dir. NonceFile = "nonce.txt" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UserdataConfig ¶
type UserdataConfig interface {
// Configure is a convenience function that updates the cloudinit.Config
// with appropriate configuration. It will run ConfigureBasic() and
// ConfigureJuju()
Configure() error
// ConfigureBasic updates the provided cloudinit.Config with
// basic configuration to initialise an OS image.
ConfigureBasic() error
// ConfigureJuju updates the provided cloudinit.Config with configuration
// to initialise a Juju machine agent.
ConfigureJuju() error
}
UserdataConfig is the bridge between instancecfg and cloudinit It supports different levels of configuration for instances
func NewUserdataConfig ¶
func NewUserdataConfig(icfg *instancecfg.InstanceConfig, conf cloudinit.CloudConfig) (UserdataConfig, error)
UserdataConfig is supposed to take in an instanceConfig as well as a cloudinit.cloudConfig and add attributes in the cloudinit structure based on the values inside instanceConfig and on the series
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
The cloudinit package implements a way of creating a cloud-init configuration file.
|
The cloudinit package implements a way of creating a cloud-init configuration file. |
|
This package offers userdata in a gzipped format to be used by different cloud providers
|
This package offers userdata in a gzipped format to be used by different cloud providers |
Click to show internal directories.
Click to hide internal directories.